mfxEncodeCtrl

Struct mfxEncodeCtrl 

#[repr(C)]
pub struct mfxEncodeCtrl { pub Header: mfxExtBuffer, pub reserved: [mfxU32; 4], pub reserved1: mfxU16, pub MfxNalUnitType: mfxU16, pub SkipFrame: mfxU16, pub QP: mfxU16, pub FrameType: mfxU16, pub NumExtParam: mfxU16, pub NumPayload: mfxU16, pub reserved2: mfxU16, pub ExtParam: *mut *mut mfxExtBuffer, pub Payload: *mut *mut mfxPayload, }
Contains parameters for per-frame based encoding control.

Fields

Header: mfxExtBuffer

< This extension buffer doesn’t have assigned buffer ID. Ignored.

reserved: [mfxU32; 4]reserved1: mfxU16MfxNalUnitType: mfxU16

Type of NAL unit that contains encoding frame. All supported values are defined by MfxNalUnitType enumerator. Other values defined in ITU-T H.265 specification are not supported.

The encoder uses this field only if application sets mfxExtCodingOption3::EnableNalUnitType option to ON during encoder initialization.

@note Only encoded order is supported. If application specifies this value in display order or uses value inappropriate for current frame or invalid value, then the encoder silently ignores it.

SkipFrame: mfxU16

< Indicates that current frame should be skipped or the number of missed frames before the current frame. See mfxExtCodingOption2::SkipFrame for details.

QP: mfxU16

< If nonzero, this value overwrites the global QP value for the current frame in the constant QP mode.

FrameType: mfxU16

Encoding frame type. See the FrameType enumerator for details. If the encoder works in the encoded order, the application must specify the frame type. If the encoder works in the display order, only key frames are enforceable.

NumExtParam: mfxU16

< Number of extra control buffers.

NumPayload: mfxU16

< Number of payload records to insert into the bitstream.

reserved2: mfxU16ExtParam: *mut *mut mfxExtBuffer

Pointer to an array of pointers to external buffers that provide additional information or control to the encoder for this frame or field pair. A typical use is to pass the VPP auxiliary data generated by the video processing pipeline to the encoder. See the ExtendedBufferID for the list of extended buffers.

Payload: *mut *mut mfxPayload

Pointer to an array of pointers to user data (MPEG-2) or SEI messages (H.264) for insertion into the bitstream. For field pictures, odd payloads are associated with the first field and even payloads are associated with the second field. See the mfxPayload structure for payload definitions.