#[repr(C)]pub struct mfxExtBuffer {
pub BufferId: mfxU32,
pub BufferSz: mfxU32,
}Expand description
The common header definition for external buffers and video processing hints.
Fields
BufferId: mfxU32< Identifier of the buffer content. See the ExtendedBufferID enumerator for a complete list of extended buffers.
BufferSz: mfxU32< Size of the buffer.