#[repr(C)]pub struct mfxFrameId {
pub TemporalId: mfxU16,
pub PriorityId: mfxU16,
pub __bindgen_anon_1: mfxFrameId__bindgen_ty_1,
}Expand description
Describes the view and layer of a frame picture.
Fields
TemporalId: mfxU16< The temporal identifier as defined in the annex H of the ITU*-T H.264 specification.
PriorityId: mfxU16< Reserved and must be zero.
__bindgen_anon_1: mfxFrameId__bindgen_ty_1Trait Implementations
Sourceimpl Clone for mfxFrameId
impl Clone for mfxFrameId
Sourcefn clone(&self) -> mfxFrameId
fn clone(&self) -> mfxFrameId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for mfxFrameId