mfxInfoMFX

Struct mfxInfoMFX 

#[repr(C)]
pub struct mfxInfoMFX { pub reserved: [mfxU32; 7], pub LowPower: mfxU16, pub BRCParamMultiplier: mfxU16, pub FrameInfo: mfxFrameInfo, pub CodecId: mfxU32, pub CodecProfile: mfxU16, pub CodecLevel: mfxU16, pub NumThread: mfxU16, pub __bindgen_anon_1: mfxInfoMFX__bindgen_ty_1, }
Specifies configurations for decoding, encoding, and transcoding processes. A zero value in any of these fields indicates that the field is not explicitly specified.

Fields

reserved: [mfxU32; 7]

< Reserved for future use.

LowPower: mfxU16

Hint to enable low power consumption mode for encoders. See the CodingOptionValue enumerator for values of this option. Use the Query API function to check if this feature is supported.

BRCParamMultiplier: mfxU16

Specifies a multiplier for bitrate control parameters. Affects the following variables: InitialDelayInKB, BufferSizeInKB, TargetKbps, MaxKbps, WinBRCMaxAvgKbps. If this value is not equal to zero, the encoder calculates BRC parameters as value * BRCParamMultiplier.

FrameInfo: mfxFrameInfo

< mfxFrameInfo structure that specifies frame parameters.

CodecId: mfxU32

< Specifies the codec format identifier in the FourCC code; see the CodecFormatFourCC enumerator for details. This is a mandated input parameter for the QueryIOSurf and Init API functions.

CodecProfile: mfxU16

< Specifies the codec profile; see the CodecProfile enumerator for details. Specify the codec profile explicitly or the API functions will determine the correct profile from other sources, such as resolution and bitrate.

CodecLevel: mfxU16

< Codec level; see the CodecLevel enumerator for details. Specify the codec level explicitly or the functions will determine the correct level from other sources, such as resolution and bitrate.

NumThread: mfxU16__bindgen_anon_1: mfxInfoMFX__bindgen_ty_1