mfxPayload

Struct mfxPayload 

#[repr(C)]
pub struct mfxPayload { pub CtrlFlags: mfxU32, pub reserved: [mfxU32; 3], pub Data: *mut mfxU8, pub NumBit: mfxU32, pub Type: mfxU16, pub BufSize: mfxU16, }
Describes user data payload in MPEG-2 or SEI message payload in H.264.

For encoding, these payloads can be inserted into the bitstream. The payload buffer must contain a valid formatted payload.

For H.264, this is the sei_message() as specified in the section 7.3.2.3.1 ‘Supplemental enhancement information message syntax’ of the ISO/IEC 14496-10 specification.

For MPEG-2, this is the section 6.2.2.2.2 ‘User data’ of the ISO/IEC 13818-2 specification, excluding the user data start_code.

For decoding, these payloads can be retrieved as the decoder parses the bitstream and caches them in an internal buffer.

@internal +———–+—————————————––+ | Codec | Supported Types | +===========+===========================================+ | MPEG2 | 0x01B2 //User Data | +———–+—————————————––+ | AVC | 02 //pan_scan_rect | | | 03 //filler_payload | | | 04 //user_data_registered_itu_t_t35 | | | 05 //user_data_unregistered | | | 06 //recovery_point | | | 09 //scene_info | | | 13 //full_frame_freeze | | | 14 //full_frame_freeze_release | | | 15 //full_frame_snapshot | | | 16 //progressive_refinement_segment_start | | | 17 //progressive_refinement_segment_end | | | 19 //film_grain_characteristics | | | 20 //deblocking_filter_display_preference | | | 21 //stereo_video_info | | | 45 //frame_packing_arrangement | +———–+—————————————––+ | HEVC | All | +———–+—————————————––+ @endinternal

Fields

CtrlFlags: mfxU32

< Additional payload properties. See the PayloadCtrlFlags enumerator for details.

reserved: [mfxU32; 3]Data: *mut mfxU8

< Pointer to the actual payload data buffer.

NumBit: mfxU32

< Number of bits in the payload data

Type: mfxU16

< MPEG-2 user data start code or H.264 SEI message type.

BufSize: mfxU16

< Payload buffer size in bytes.