#[repr(C)]pub union mfxFrameData__bindgen_ty_3 {
pub Y: *mut mfxU8,
pub Y16: *mut mfxU16,
pub R: *mut mfxU8,
}Expand description
@name Color Planes Data pointers to corresponding color channels (planes). The frame buffer pointers must be 16-byte aligned. The application has to specify pointers to all color channels even for packed formats. For example, for YUY2 format the application must specify Y, U, and V pointers. For RGB32 format, the application must specify R, G, B, and A pointers. / /*! @{
Fields
Y: *mut mfxU8< Y channel.
Y16: *mut mfxU16< Y16 channel.
R: *mut mfxU8< R channel.