#[repr(C)]pub union mfxStructVersion {
pub __bindgen_anon_1: mfxStructVersion__bindgen_ty_1,
pub Version: mfxU16,
}Expand description
Introduce the field Version for any structure. Assumed that any structure changes are backward binary compatible. mfxStructVersion starts from {1,0} for any new API structures. If mfxStructVersion is added to the existent legacy structure (replacing reserved fields) it starts from {1, 1}.
Fields
__bindgen_anon_1: mfxStructVersion__bindgen_ty_1Version: mfxU16< Structure version number.