#[repr(C)]pub struct mfxBitstream {
pub __bindgen_anon_1: mfxBitstream__bindgen_ty_1,
pub DecodeTimeStamp: mfxI64,
pub TimeStamp: mfxU64,
pub Data: *mut mfxU8,
pub DataOffset: mfxU32,
pub DataLength: mfxU32,
pub MaxLength: mfxU32,
pub PicStruct: mfxU16,
pub FrameType: mfxU16,
pub DataFlag: mfxU16,
pub reserved2: mfxU16,
}Expand description
Defines the buffer that holds compressed video data.
Fields
__bindgen_anon_1: mfxBitstream__bindgen_ty_1DecodeTimeStamp: mfxI64Decode time stamp of the compressed bitstream in units of 90KHz. A value of MFX_TIMESTAMP_UNKNOWN indicates that there is no time stamp.
This value is calculated by the encoder from the presentation time stamp provided by the application in the mfxFrameSurface1 structure and from the frame rate provided by the application during the encoder initialization.
TimeStamp: mfxU64< Time stamp of the compressed bitstream in units of 90KHz. A value of MFX_TIMESTAMP_UNKNOWN indicates that there is no time stamp.
Data: *mut mfxU8< Bitstream buffer pointer, 32-bytes aligned.
DataOffset: mfxU32< Next reading or writing position in the bitstream buffer.
DataLength: mfxU32< Size of the actual bitstream data in bytes.
MaxLength: mfxU32< Allocated bitstream buffer size in bytes.
PicStruct: mfxU16< Type of the picture in the bitstream. Output parameter.
FrameType: mfxU16< Frame type of the picture in the bitstream. Output parameter.
DataFlag: mfxU16< Indicates additional bitstream properties. See the BitstreamDataFlag enumerator for details.
reserved2: mfxU16< Reserved for future use.