#[repr(C)]pub struct mfxBitstream__bindgen_ty_1__bindgen_ty_1 {
pub EncryptedData: *mut mfxEncryptedData,
pub ExtParam: *mut *mut mfxExtBuffer,
pub NumExtParam: mfxU16,
pub reserved1: mfxU16,
pub CodecId: mfxU32,
}Fields
EncryptedData: *mut mfxEncryptedData< Reserved and must be zero.
ExtParam: *mut *mut mfxExtBuffer< Array of extended buffers for additional bitstream configuration. See the ExtendedBufferID enumerator for a complete list of extended buffers.
NumExtParam: mfxU16< The number of extended buffers attached to this structure.
reserved1: mfxU16< Reserved for future use.
CodecId: mfxU32< Specifies the codec format identifier in the FourCC code. See the CodecFormatFourCC enumerator for details. This optional parameter is required for the simplified decode initialization.