#[repr(C)]pub struct mfxFrameData {Show 16 fields
pub __bindgen_anon_1: mfxFrameData__bindgen_ty_1,
pub NumExtParam: mfxU16,
pub reserved: [mfxU16; 9],
pub MemType: mfxU16,
pub PitchHigh: mfxU16,
pub TimeStamp: mfxU64,
pub FrameOrder: mfxU32,
pub Locked: mfxU16,
pub __bindgen_anon_2: mfxFrameData__bindgen_ty_2,
pub __bindgen_anon_3: mfxFrameData__bindgen_ty_3,
pub __bindgen_anon_4: mfxFrameData__bindgen_ty_4,
pub __bindgen_anon_5: mfxFrameData__bindgen_ty_5,
pub A: *mut mfxU8,
pub MemId: mfxMemId,
pub Corrupted: mfxU16,
pub DataFlag: mfxU16,
}Expand description
Describes frame buffer pointers.
Fields
__bindgen_anon_1: mfxFrameData__bindgen_ty_1NumExtParam: mfxU16< The number of extra configuration structures attached to this structure.
reserved: [mfxU16; 9]< Reserved for future use.
MemType: mfxU16< Allocated memory type. See the ExtMemFrameType enumerator for details. Used for better integration of 3rd party plugins into the pipeline.
PitchHigh: mfxU16< High 16 bits of the Distance in bytes between the start of two consecutive rows in a frame. App should combine with the low 16 bits which is stored in PitchLow to get the final Pitch. finalPitch = (PitchHigh << 16) + PitchLow.
TimeStamp: mfxU64< Time stamp of the video frame in units of 90KHz. Divide TimeStamp by 90,000 (90 KHz) to obtain the time in seconds. A value of MFX_TIMESTAMP_UNKNOWN indicates that there is no time stamp.
FrameOrder: mfxU32< Current frame counter for the top field of the current frame. An invalid value of MFX_FRAMEORDER_UNKNOWN indicates that API functions that generate the frame output do not use this frame.
Locked: mfxU16< Counter flag for the application. If Locked is greater than zero then the application locks the frame or field pair. Do not move, alter or delete the frame.
__bindgen_anon_2: mfxFrameData__bindgen_ty_2__bindgen_anon_3: mfxFrameData__bindgen_ty_3__bindgen_anon_4: mfxFrameData__bindgen_ty_4__bindgen_anon_5: mfxFrameData__bindgen_ty_5A: *mut mfxU8< A channel.
MemId: mfxMemId< Memory ID of the data buffers. Ignored if any of the preceding data pointers is non-zero.
Corrupted: mfxU16< Some part of the frame or field pair is corrupted. See the Corruption enumerator for details.
DataFlag: mfxU16< Additional flags to indicate frame data properties. See the FrameDataFlag enumerator for details.