#[repr(C)]pub struct mfxInitParam {
pub Implementation: mfxIMPL,
pub Version: mfxVersion,
pub ExternalThreads: mfxU16,
pub __bindgen_anon_1: mfxInitParam__bindgen_ty_1,
pub GPUCopy: mfxU16,
pub reserved: [mfxU16; 21],
}Expand description
Specifies advanced initialization parameters. A zero value in any of the fields indicates that the corresponding field is not explicitly specified.
Fields
Implementation: mfxIMPL< Enumerator that indicates the desired legacy Intel(r) Media SDK implementation.
Version: mfxVersion< Structure which specifies minimum library version or zero, if not specified.
ExternalThreads: mfxU16< Desired threading mode. Value 0 means internal threading, 1 - external.
__bindgen_anon_1: mfxInitParam__bindgen_ty_1GPUCopy: mfxU16< Enables or disables GPU accelerated copying between video and system memory in legacy Intel(r) Media SDK components. See the GPUCopy enumerator for a list of valid values.
reserved: [mfxU16; 21]Trait Implementations
Sourceimpl Clone for mfxInitParam
impl Clone for mfxInitParam
Sourcefn clone(&self) -> mfxInitParam
fn clone(&self) -> mfxInitParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for mfxInitParam