mfxVideoParam

Struct mfxVideoParam 

#[repr(C)]
pub struct mfxVideoParam { pub AllocId: mfxU32, pub reserved: [mfxU32; 2], pub reserved3: mfxU16, pub AsyncDepth: mfxU16, pub __bindgen_anon_1: mfxVideoParam__bindgen_ty_1, pub Protected: mfxU16, pub IOPattern: mfxU16, pub ExtParam: *mut *mut mfxExtBuffer, pub NumExtParam: mfxU16, pub reserved2: mfxU16, }
Configuration parameters for encoding, decoding, transcoding, and video processing.

Fields

AllocId: mfxU32

Unique component ID that will be passed by the library to mfxFrameAllocRequest. Useful in pipelines where several components of the same type share the same allocator.

reserved: [mfxU32; 2]reserved3: mfxU16AsyncDepth: mfxU16

Specifies how many asynchronous operations an application performs before the application explicitly synchronizes the result. If zero, the value is not specified.

__bindgen_anon_1: mfxVideoParam__bindgen_ty_1Protected: mfxU16

Specifies the content protection mechanism. See the Protected enumerator for a list of supported protection schemes.

IOPattern: mfxU16

Input and output memory access types for functions. See the enumerator IOPattern for details. The Query API functions return the natively supported IOPattern if the Query input argument is NULL. This parameter is a mandated input for QueryIOSurf and Init API functions. The output pattern must be specified for DECODE. The input pattern must be specified for ENCODE. Both input and output pattern must be specified for VPP.

ExtParam: *mut *mut mfxExtBuffer

< Points to an array of pointers to the extra configuration structures. See the ExtendedBufferID enumerator for a list of extended configurations. The list of extended buffers should not contain duplicated entries, such as entries of the same type. If the mfxVideoParam structure is used to query library capability, then the list of extended buffers attached to the input and output mfxVideoParam structure should be equal, that is, it should contain the same number of extended buffers of the same type.

NumExtParam: mfxU16

< The number of extra configuration structures attached to this structure.

reserved2: mfxU16