pub type mfxIMPL = mfxI32;Expand description
This enumerator itemizes implementation types. The implementation type is a bit OR’ed value of the base type and any decorative flags. @note This enumerator is for legacy dispatcher compatibility only. The new dispatcher does not use it.